ajdmom.mdl\_2fsvj.mom
=====================

.. automodule:: ajdmom.mdl_2fsvj.mom

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      dm
      dpoly
      m
      moment_y
      poly2num
   
   

   
   
   

   
   
   



